@@ -51,17 +51,12 @@ def run_external_program(cmdstring, wdir, argument):
     else:
         cmdline = cmdstring % argument
     wdir = os.path.normpath(wdir)
-    dir_up = wdir.count("/") * "../" + ".."
+    cur_dir = os.getcwd()
     v = cmdline.split()
     v = v[:1] + v
-    os.chdir(wdir)
     if not os.path.exists(v[0]):
         raise RunExternalFailed(v)
-        #self.m_ui.display_error_message("'%s' does not exist." %v[0],
-        #        _("Running external program failed"))
-        os.chdir(dir_up)
         return
-    os.chdir(dir_up)
     try:
         if __child_pid is not None:
             os.kill(__child_pid, signal.SIGKILL)
@@ -79,12 +74,11 @@ def run_external_program(cmdstring, wdir, argument):
         except OSError, x:
             print >> sys.stderr, "OS Error:", x
             os._exit(-1)
-            os.chdir("..")
-        os.chdir("..")
+            os.chdir(cur_dir)
+        os.chdir(cur_dir)
     else:
         __child_pid = pid
 
-
 class SolfegeApp(cfg.ConfigUtils):
     def __init__(self, argv, ui):
         cfg.ConfigUtils.__init__(self, 'solfege-app')
