@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -95,8 +95,10 @@ predef = {'dictation': 'dictation',
           'id-by-name': 'id-by-name',
           'normal': 'normal',
           'voice': 'voice',
+          'rvoice': 'rvoice',
           'satb': 'satb',
           'cmdline': 'cmdline',
+          'wavfile': 'wavfile',
           'horiz': 'horiz',
           'vertic': 'vertic',
           'yes': True,
@@ -106,17 +108,17 @@ predef = {'dictation': 'dictation',
           'semitones': 'semitones',
           'tempo': (60, 4)}
 
-class WavPlayerFunctionClass(object):
-    def __init__(self, args):
-        self.m_args = args
-    def __str__(self):
-        return cfg.get_string("sound/wav_player") + " " + self.m_args
-
 lessonfile_functions = {
         '_': dataparser.dataparser_i18n_func,
         '_i': _i, #FIXME
-        'play_wav': lambda f: WavPlayerFunctionClass(f),
+        'play_wav': lambda f: Music(cfg.get_string("sound/wav_player") + " " + f, "cmdline"),
         'music': lambda m, t='normal': Music(m, t),
+        'chord': lambda m: Music(m, 'chord'),
+        'satb': lambda m: Music(m, 'satb'),
+        'voice': lambda m: Music(m, 'voice'),
+        'rvoice': lambda m: Music(m, 'rvoice'),
+        'cmdline': lambda m: Music(m, 'cmdline'),
+        'wavfile': lambda m: Music(m, 'wavfile'),
 }
 
 class _Header:
@@ -172,11 +174,13 @@ class LessonfileCommon(object):
             question['active'] = 1
             # FIXMECOMPAT
             if isinstance(question['music'], basestring):
+                # The following line is for backward compatibility
                 question['music'] = Music(question['music'], self.header.musicformat)
             question['m_lessonfile'] = self
     def select_random_question(self):
         """
-        Select a new question by random.
+        Select a new question by random. It will use the music in the
+        lesson file question variable 'music' when selecting transposition.
         """
         count = 0
         available_question_idx = []
@@ -194,7 +198,7 @@ class LessonfileCommon(object):
                 if self.header.random_transpose == True:
                     self.handle_random_transpose_is_yes()
                 # Backward compatability to handle old style
-                # random_transpose = -4, 5 FIXME
+                # random_transpose = -4, 5 FIXMECOMPAT
                 elif len(self.header.random_transpose) == 2:
                     self.header.random_transpose \
                         = ['semitones'] + self.header.random_transpose
@@ -204,6 +208,8 @@ class LessonfileCommon(object):
                     key = "c \major"
                 if self.header.random_transpose[0] == 'semitones':
                     self.m_transpose = self.semitone_find_random_transpose()
+                    if random.randint(0, 1):
+                        self.m_transpose.enharmonic_flip()
                 else:
                     self.m_transpose = self.find_random_transpose(key)
             if count == 10:
@@ -219,16 +225,15 @@ class LessonfileCommon(object):
         Create and return a random MusicalPitch representing this transposition.
         """
         assert self.header.random_transpose[0] == 'semitones'
-        if self.header.random_transpose == 1:
-            return mpd.MusicalPitch().randomize("g", "fis'")
-        elif type(self.header.random_transpose) in (type([]), type(())):
-            return mpd.MusicalPitch().randomize(
+        return mpd.MusicalPitch().randomize(
               mpd.transpose_notename("c'", self.header.random_transpose[1]),
               mpd.transpose_notename("c'", self.header.random_transpose[2]))
     def find_random_transpose(self, key):
         """
         Called to create random transposition in "accidentals" or "key" mode.
         Create and return a random MusicalPitch representing this transposition.
+        Keyword arguments:
+        key -- the key the question is written in, for example "c \major"
         """
         assert self.header.random_transpose[0] in ('key', 'accidentals')
         low, high = self.header.random_transpose[1:3]
@@ -256,7 +261,7 @@ class LessonfileCommon(object):
         interv.set_from_string(_keys_to_interval[random.choice(range(n_down, n_up+1))])
         return mpd.MusicalPitch.new_from_notename("c'") + interv
     def handle_random_transpose_is_yes(self):
-        self.header.random_transpose = ['semitones', -5, 6]
+        self.header.random_transpose = ['key', -5, 5]
     def iterate_questions_with_unique_names(self):
         """Iterate the questions in the lessonfile, but only yield the
         first question if several questions have the same name. The
@@ -311,8 +316,45 @@ class LessonfileCommon(object):
         elif question[varname].m_musictype == 'voice':
             return r"\staff\transpose %s{ %s }" \
               % (self.m_transpose.get_octave_notename(), question[varname].m_musicdata)
+        elif question[varname].m_musictype == 'rvoice':
+            def find_first_note(v):
+                """arg v is a list of the musicdata splittet by whitespace.
+                Return the index of the first note.
+                """
+                #FIXME tidy up a little
+                i = 0
+                while 1:
+                    n = re.match("(\<?)[a-zA-Z]+[',]*", v[i])
+                    if n:
+                        break
+                    if v[i] == r"\clef":
+                        i += 2
+                    elif v[i] == r"\key":
+                        i += 3
+                    elif v[i] == r"\time":
+                        i += 2
+                    else:
+                        i += 1
+                    if i >= len(v):
+                        return -1
+                return i
+            v = question[varname].m_musicdata.split()
+            i = find_first_note(v)
+            if i == -1:
+                return r"\staff\transpose %s{ %s }"\
+                   % (self.m_transpose.get_octave_notename(), " ".join(v))
+            m = re.match("(?P<pre>\<?)(?P<note>[a-zA-Z]+[',]*)", v[i])
+            rel_note = m.group('note')
+            nn = mpd.MusicalPitch.new_from_notename(rel_note)
+            aa = m.group('pre') + nn.get_octave_notename()
+            v[i] = m.group('pre') + nn.get_notename() + v[i][len(aa)::]
+            return r"\staff\transpose %s\relative %s{ %s }" \
+              % (self.m_transpose.get_octave_notename(), 
+                 rel_note, " ".join(v))
         elif question[varname].m_musictype == 'cmdline':
             return str(question[varname])
+        elif question[varname].m_musictype == 'wavfile':
+            return question[varname].m_musicdata
         else:
             raise LessonfileException("\nUknown music type: '%s'" % question[varname].m_musictype)
     def get_music(self):
@@ -364,7 +406,8 @@ class LessonfileCommon(object):
     def get_music_as_notename_list(self, varname):
         """
         Return a list of notenames from the variabale VARNAME in the
-        currently selected question.
+        currently selected question. The notes are transposed if
+        header.random_transpose is set.
 
         Assert m_musictype in ('chord', 'satb')
         """
@@ -387,9 +430,10 @@ class LessonfileCommon(object):
         else:
             raise LessonfileException("get_music_as_notename_list cannot handle m_musictype==%s" % music.m_musictype)
     def get_music_as_notename_string(self, varname):
-        """FIXME update version string. Why the fuck do we need this function??
+        """
         Return a string with notenames representing the question currently
-        selected question.
+        selected question. The notes are transposed if
+        header.random_transpose is set.
 
         Assert musicformat in ('chord', 'satb')
         """
@@ -407,7 +451,11 @@ class LessonfileCommon(object):
             question = self.get_question()
         if question[varname].m_musictype == 'cmdline':
             app.run_external_program(str(question[varname].m_musicdata), cfg.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')), "")
-        elif question[varname].m_musictype in ('normal', 'satb', 'voice'):
+        elif question[varname].m_musictype == 'wavfile':
+            soundcard.play_wav_file(os.path.join(
+                self.m_t.get_string('lessoncollections/%s' % self.m_t.get_string('lessoncollection')),
+                question[varname].m_musicdata))
+        elif question[varname].m_musictype in ('normal', 'satb', 'voice', 'rvoice'):
             self.play_question_musicformat_normal_satb(question)
         elif question[varname].m_musictype in 'chord':
             self.play_question_musicformat_chord(question)
@@ -420,10 +468,10 @@ class LessonfileCommon(object):
     def play_question_slowly(self, question=None):
         if not question:
             question = self.get_question()
-        assert question['music'].m_musictype == 'normal'
+        #assert question['music'].m_musictype == 'normal'
+        #FIXME what music types should be handled differently
         self.play_question_musicformat_normal_slowly(question)
     def play_question_musicformat_normal_slowly(self, question):
-        assert question['music'].m_musictype == 'normal'
         instrument = self.prepare_instrument_list(question)
         bpm = self.get_tempo()
         bpm = (bpm[0]/2, bpm[1])
@@ -685,7 +733,7 @@ class ChordLessonfile(LessonfileCommon):
         """
         assert self._idx is not None
         if 'inversion' in self.m_questions[self._idx]:
-             return self.m_questions[self._idx]['inversion']
+            return self.m_questions[self._idx]['inversion']
         return -1
     def get_toptone(self):
         """
@@ -704,7 +752,7 @@ class LessonFileManager:
         self.m_db = {}
         self.m_invalid_files = []
         vim_tmpfile_re = re.compile("\..*\.swp")
-        for collection in cfg.get_string("config/lessoncollections").split():
+        for collection in cfg.get_list("config/lessoncollections"):
             self.m_db[collection] = {}
             if not os.path.isdir(os.path.expanduser(cfg.get_string("lessoncollections/%s" % collection))):
                 continue
@@ -786,7 +834,7 @@ class LessonFileManager:
 
 if __name__ == '__main__':
     import time
-    t1=time.clock()
+    t1 = time.clock()
     cfg.initialise(None, "default.config",
         "~/.solfegerc")
     t2 = time.clock()
