@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -179,6 +179,7 @@ import utils, history
 from configwindow import ConfigWindow
 import soundcard
 import mpd, mpd.musicdisplayer, gu, cfg
+import stock
 
 
 # The order the modules are imported affect the ordering in the menus.
@@ -195,13 +196,13 @@ exercise_setup.register_exercise({
     'exercise_config': 'solfege/scales',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("_Scales")),
     'toolbar': 4.5,
-    'icon': 'graphics/identifyscale24.png',
+    'stock-icon': 'solfege-identify-scale',
 })
 exercise_setup.register_exercise({
     'exercise_name': 'id-by-name',
     'exercise_config': 'solfege/scales-thirds',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("Scales in t_hirds")),
-    'icon': 'graphics/identifyscale24.png',
+    'stock-icon': 'solfege-identify-scale',
 })
 
 
@@ -258,13 +259,13 @@ class MusicViewerWindow(gtk.Dialog):
         fontsize = cfg.get_int('config/feta_font_size=20')
         self.g_music_displayer.display(music, fontsize)
 
-
 class MainWin(gnome.ui.App, cfg.ConfigUtils):
     def __init__(self, argv):
-        gnome.ui.App.__init__(self, 'solfege19', 'GNU Solfege')
+        gnome.ui.App.__init__(self, 'solfege', 'GNU Solfege')
+        self.icons = stock.SolfegeIconFactory(self, configureoutput.datadir)
         self.set_default_size(400, 400)
-        self.set_icon(gtk.gdk.pixbuf_new_from_file(
-                os.path.join("graphics", "solfege.png")))
+        pixbuf = self.render_icon('solfege-icon', gtk.ICON_SIZE_DIALOG)
+        self.set_icon(pixbuf)
         cfg.ConfigUtils.__dict__['__init__'](self, 'mainwin')
         self.set_resizable(self.get_bool('gui/mainwin_user_resizeable'))
         self.connect('destroy', self.quit_program)
@@ -323,6 +324,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             trans = _("SOLFEGETRANSLATORS")
             if trans == 'SOLFEGETRANSLATORS':
                 trans = ""
+            pixbuf = self.render_icon('solfege-icon', gtk.ICON_SIZE_DIALOG)
             self.g_about_window = gnome.ui.About("GNU Solfege",
                   configureoutput.VERSION_STRING,
                   "Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen",
@@ -334,8 +336,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                   'Joe Lee %s' % _("(sound code for the MS Windows port)"),
                   ],
                   ["Tom Cato Amundsen"],
-                  trans,
-                  gtk.gdk.pixbuf_new_from_file(os.path.join("graphics", "solfege.png")))
+                  trans, pixbuf)
             #self.g_about_window.connect('destroy', self.hide_about_window)
             #self.g_about_window.show()
             #FIXME this sucks.
@@ -452,6 +453,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                 im.set_from_file(d['icon'])
                 im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
                 menuitem.set_image(im)
+            elif 'stock-icon' in d:
+                im = gtk.Image()
+                im.set_from_stock(d['stock-icon'], gtk.ICON_SIZE_MENU)
+                menuitem.set_image(im)
             if 'exercise_config' in d:
                 s = 'solfege:practise/%s/%s' % (d['exercise_name'], d['exercise_config'])
             else:
@@ -643,7 +648,11 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             im = gtk.Image()
             if 'toolbar' not in ex:
                 continue
-            im.set_from_file(ex['icon'])
+            if ex.has_key('icon'):
+                im.set_from_file(ex['icon'])
+            else:
+                assert ex.has_key('stock-icon')
+                im.set_from_stock(ex['stock-icon'], gtk.ICON_SIZE_SMALL_TOOLBAR)
             button = self.g_toolbar.append_item(ex['exercise_pretty_name'], ex['exercise_pretty_name'], None, im, None, None)
             button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href("solfege:practice/"+ex['exercise_name']+'/'+ex['exercise_config']))
         self.add_toolbar(self.g_toolbar, "toolbar", "normal", "top", 1, 0, 1)
@@ -674,9 +683,7 @@ def create_menu_item(txt, callback, ag, accel_key, accel_mod):
 if splash_win:
     splash_win.show_progress("running gnome.program_init")
 
-gnome.program_init('solfege%s%s' % (configureoutput.MAJOR_VERSION,
-                                    configureoutput.MINOR_VERSION),
-                   configureoutput.VERSION_STRING)
+gnome.program_init('solfege', configureoutput.VERSION_STRING)
 prog = gnome.program_get()
 prog.parse_args()
 
