@@ -25,7 +25,7 @@ if __name__ == '__main__':
     import i18n
     i18n.setup_srcdir()
 
-import gtk
+import gtk, gobject
 import mpd, gu, cfg
 import gobject
 
@@ -71,21 +71,21 @@ class NotenameSpinButton(gtk.HBox):
         self.m_timeout = None
     def on_up_press(self, eb, ev):
         if self.m_timeout:
-            gtk.timeout_remove(self.m_timeout)
+            gobject.source_remove(self.m_timeout)
             self.m_timeout = None
         if ev.type == gtk.gdk.BUTTON_PRESS:
             if self.m_value < 127:
                 self.up()
             if self.m_value < 127:
-                self.m_timeout = gtk.timeout_add(DELAY1, self.on_up_timeout)
+                self.m_timeout = gobject.timeout_add(DELAY1, self.on_up_timeout)
     def on_up_release(self, eb, ev):
         if self.m_timeout:
-            gtk.timeout_remove(self.m_timeout)
+            gobject.source_remove(self.m_timeout)
             self.m_timeout = None
     def on_up_timeout(self, *v):
         if self.m_value < 127:
             self.up()
-            self.m_timeout = gtk.timeout_add(DELAY2, self.on_up_timeout)
+            self.m_timeout = gobject.timeout_add(DELAY2, self.on_up_timeout)
     def up(self):
         self.m_value += 1
         self.g_label.set_text(mpd.int_to_user_notename(self.m_value))
@@ -93,21 +93,21 @@ class NotenameSpinButton(gtk.HBox):
         self.emit('value-changed', self.m_value)
     def on_down_press(self, eb, ev):
         if self.m_timeout:
-            gtk.timeout_remove(self.m_timeout)
+            gobject.source_remove(self.m_timeout)
             self.m_timeout = None
         if ev.type == gtk.gdk.BUTTON_PRESS:
             if self.m_value > 0:
                 self.down()
             if self.m_value > 0:
-                self.m_timeout = gtk.timeout_add(DELAY1, self.on_down_timeout)
+                self.m_timeout = gobject.timeout_add(DELAY1, self.on_down_timeout)
     def on_down_release(self, eb, ev):
         if self.m_timeout:
-            gtk.timeout_remove(self.m_timeout)
+            gobject.source_remove(self.m_timeout)
             self.m_timeout = None
     def on_down_timeout(self, *v):
         if self.m_value > 0:
             self.down()
-            self.m_timeout = gtk.timeout_add(DELAY2, self.on_down_timeout)
+            self.m_timeout = gobject.timeout_add(DELAY2, self.on_down_timeout)
     def down(self):
         self.m_value -= 1
         self.g_label.set_text(mpd.int_to_user_notename(self.m_value))
@@ -171,7 +171,6 @@ class nNotenameRangeController(NotenameRangeController, cfg.ConfigUtils):
 
 def _test():
     w = gtk.Window(gtk.WINDOW_TOPLEVEL)
-    #w.set_size_request(100, 100)
     vbox = gtk.VBox()
     w.add(vbox)
     #####
